__AuthToken__   = ""
__Sender__      = ""
__APIKey__      = ""
__APIVersion__  = "2.02"
__APIURL__      = "https://api.tnz.co.nz/api/v"+__APIVersion__;
#__APIURL__      = "http://127.0.0.1:8060/api/v"+__APIVersion__;
__APIHeaders__  = {
    "Content-Type": "application/json",
    "Accept": "application/json",
    "encoding": "utf-8"
}